@@ -5,4 +5,4 @@ from ..xml import update_project_file
 def set_command(args):
     logger.debug(args)
     dir_args = vars(args)
-    update_project_file(dir_args)
+    return update_project_file(dir_args)
