@@ -1,9 +1,11 @@
 import os
 import time
 import multiprocessing as mp
+from datetime import datetime
 
 import pytest
 
+from squirrel import xml
 from squirrel.squirrel import _main
 
 
@@ -27,8 +29,16 @@ def initialized(test_directory):
 
 @pytest.fixture
 def watching(initialized):
-    watch = mp.Process(target=_main, args=(['watch', 'start', '--daemon'],))
+    watch = mp.Process(target=_main, args=(['watch', 'start', '-d'],))
     watch.start()
-    time.sleep(5)
+    watch.join()
     yield True
     _main(['watch', 'stop'])
+
+
+@pytest.fixture
+def one_watch_added(initialized):
+    count = 1
+    now = datetime.now()
+    xml.add_watch_entry(count, now)
+    yield (count, now)
